// -----------------------------------------------------------
// SendingMessageListener.java
// -----------------------------------------------------------

package cz.vutbr.wsagent.bscomm;


import cz.vutbr.wsagent.comm.ISendListener;
import java.awt.event.ActionEvent;

/**
 * The Listener for sending messages. It implements <code>ISendListener</code>.
 * @author Martin Gábor
 * @see ISendListener
 */
public class SendingResultListener implements ISendListener{


    private volatile boolean ready = false;


    /**
     * Sets that the message has been send.
     */
    public void actionPerformed(ActionEvent arg0) {

        setReady(true); 
    }


    /**
     * Waits for response
     * @param timeInterval Time of waiting.
     */
    public void waitForResponse(int timeInterval) throws TimeExpiredException{


        long startTime = System.currentTimeMillis();
        long endTime;


        //
        do{
            endTime = System.currentTimeMillis();
        } while (!isReady() && (endTime - startTime < timeInterval));

        if (!isReady())
            throw new TimeExpiredException();

    }

    /**
     * Get the value of ready
     *
     * @return the value of ready
     */
    public synchronized boolean isReady() {
        return ready;
    }

    /**
     * Set the value of ready
     *
     * @param isReady new value of ready
     */
    public synchronized void setReady(boolean isReady) {
        this.ready = isReady;
    }

}
